@@ -311,7 +311,8 @@ sub GetPersistent
 	my ($self, $var) = @_;
 	my ($sql, $val);
 	my $id;
-	my $table = "sessions";
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."sessions";
 	my $dbh = $self->SYS_DBH();
 
 	$self->ValidatePersistent;
@@ -338,8 +339,11 @@ sub SetPersistent
 sub ErasePersistent
 {
 	my $self = shift;
+
 	$self->ValidatePersistent;
-	my $table = "sessions";
+
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."sessions";
 	my $id = $self->{session_id};
 	my $sql = "DELETE FROM $table
                    WHERE session_id = '$id'";
@@ -351,10 +355,10 @@ sub ValidatePersistent
 {
 	my $self = shift;
 
-	my ($id, $sql);
+	my ($id, $sql, $sth, @other, $other);
 	my $now = time;
-	my $table = "sessions";
-	my ($sql, $sth, @other, $other);
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."sessions";
 	my $expire = YMD(time - 60 * $HTML::Merge::Ini::SESSION_TIMEOUT);
 	$self->CheckSessionTable;
 	$self->GetSessionID;
@@ -364,7 +368,7 @@ sub ValidatePersistent
                 FROM $table
                 WHERE varname = ''
                 AND vardata < '$expire'";
-	my @other = $self->LoadArray($sql);
+	@other = $self->LoadArray($sql);
 	return unless @other;
 	$sql = "DELETE FROM $table WHERE session_id IN ('" .
 		join("','", @other) . "')";
@@ -377,7 +381,8 @@ sub CreateSessionTable
 	my $self = shift;
 
 	my $dbh;
-	my $table = "sessions";
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."sessions";
 	my $ddl = "CREATE TABLE $table (
 			session_id VARCHAR(20) NOT NULL,
 			varname VARCHAR(30) NOT NULL,
@@ -402,7 +407,9 @@ sub CreateSessionTable
 sub CheckSessionTable
 {
 	my $self = shift;
-	my $table = "sessions";
+
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."sessions";
 	my $sql = "SELECT Count(*) FROM $table";
 	my $sth;
 
@@ -432,7 +439,8 @@ sub GetSessionID
 	my $created = $self->MakeSessionID;
 	return if $created;
 	my $id = $self->{session_id};
-	my $table = "sessions";
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."sessions";
 	my $sql = "SELECT Count(*) 
 		FROM $table
                 WHERE session_id = '$id'
@@ -451,7 +459,8 @@ sub MakeSessionID
 	my $self = shift;
 	my ($key, $val);
 	my $sql;
-	my $table = "sessions";
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."sessions";
 	my $expire=undef;
 
 	return 0 if $self->{session_id};
@@ -500,7 +509,8 @@ sub SetField
 	my ($self, $key, $val) = @_;
 
 	my ($sql, $count, $sth);
-	my $table = "sessions";
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."sessions";
 	my $id = $self->{session_id};
 	
 	$sql = "SELECT Count(*)
@@ -592,14 +602,70 @@ sub SetCookie
 	$ENV{'HTTP_COOKIE'} .= "$name=$value";
 }
 ###########################################
-#sub import 
-#{
-#	my (@param) = @_;
-#
-#	return if ($param[1] eq ':unconfig');
-#
-#	&ReadConfig;
-#}
+sub ReadConfig 
+{
+	my $self = $0;
+	$self =~ s/\.\w+$/.conf/;
+	my @conf = ($self, "/etc/merge.conf", &GetHome . "/.merge");
+
+	foreach my $f (@conf) 
+	{
+        	if (open(CFG, $f))
+	 	{
+			no strict;
+			my $code = join("", <CFG>);
+			close(CFG);
+			eval $code;
+			if ($@) 
+			{
+				print "Status: 501 Server error\n";
+				print "Content-type: text/plain\n\n";
+				print "$f caused error: $@";
+				exit;
+			}
+
+			$HTML::Merge::config = $f;
+        	        last;
+	        }
+	}
+
+	$self =~ s/\.\w+$/.ext/;
+	foreach my $ext (($self, "/etc/merge.ext")) 
+	{
+		if (-f $self) 
+		{
+			package HTML::Merge::Ext;
+			eval 'require $self;';
+			if ($@) 
+			{
+				print "Status: 501 Server error\n";
+				print "Content-type: text/plain\n\n";
+				print "$self caused error: $@";
+				exit;
+			}
+		}
+	}
+}
+###############################################################################
+sub GetHome 
+{
+	return if ($^O =~ /Win/);
+
+	my ($name,$passwd,$uid,$gid,
+        $quota,$comment,$gcos,$dir,$shell,$expire) = getpwuid($>);
+
+	return $dir;
+}
+###############################################################################
+sub import 
+{
+	my (@param) = @_;
+
+	$param[1] |= '';
+	return if ($param[1] eq ':unconfig');
+
+	&ReadConfig;
+}
 ###########################################
 sub Convert 
 {
@@ -647,9 +713,14 @@ sub AddUser
 	croak "Invalid password length: $password" unless ($password =~ /^\S{3,15}$/);
 	unless ($HTML::Merge::Ini::ALLOW_EASY_PASSWORDS) 
 	{
-		require Data::Password;
-		my $reason = Data::Password::IsBadPassword($password);
-		croak "Bad password $password: $reason" if $reason;
+		$@ = undef;
+		eval{ require Data::Password; };
+
+		unless($@)
+		{
+			my $reason = Data::Password::IsBadPassword($password);
+			croak "Bad password $password: $reason" if $reason;
+		}
 	}
 
 	croak "Can't change user $user"
@@ -1586,3 +1657,4 @@ sub LoadSysTableFromFile
 ###########################################
 1;
 ###########################################
+
